@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: MapBorder.cpp,v 1.8 2007/03/25 20:48:24 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: MapBorder.cpp,v 1.9 2008/08/05 20:52:26 bpearlmutter Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -198,7 +198,7 @@ genRect(const int * xx, const int * yy, int points, GRectMapper * mapper)
 		")-(" << end_x << ", " << end_y << "), di=" << di << ", dj=" << dj << "\n");*/
       
       GPosition pos1;
-      if (di && dj || cell_cnt && (di!=last_di || dj!=last_dj) ||
+      if ((di && dj) || (cell_cnt && (di!=last_di || dj!=last_dj)) ||
 	  passed_cells[cell_i+di].search(cell_j+dj, pos1))
       {
 	 // We're either leaving the current cell through a corner or a way,
