@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: qd_tbar_mode_piece.cpp,v 1.10 2007/03/25 20:48:26 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: qd_tbar_mode_piece.cpp,v 1.11 2008/08/05 20:52:27 bpearlmutter Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -134,9 +134,13 @@ const
    if (zoom>IDC_ZOOM_MAX-IDC_ZOOM_MIN) return Invalid;
    if (zoom<=0) return Invalid;
    if (zoom<5)
-      if (str.length()==1) return Valid;
-      else return Invalid;
-   
+     {
+       if (str.length()==1)
+	 return Valid;
+       else
+	 return Invalid;
+     }
+
    if (zoom<5 || zoom>IDC_ZOOM_MAX-IDC_ZOOM_MIN) return Invalid;
    return Acceptable;
 }
