@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuMessage.cpp,v 1.21 2007/07/29 16:23:51 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: DjVuMessage.cpp,v 1.24 2008/01/27 17:32:56 leonb Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -79,9 +79,6 @@
 # include <tchar.h>
 # include <windows.h>
 # include <winreg.h>
-# ifndef __MINGW32__
-#  include <atlbase.h>
-# endif
 #endif
 #ifdef UNIX
 # include <unistd.h>
@@ -124,10 +121,9 @@ static const char localestring[]="locale";
 // directory names for searching messages
 #ifdef AUTOCONF
 static const char DjVuDataDir[] = DIR_DATADIR "/djvu/osi";
+#endif /* AUTOCONF */
 static const char ModuleDjVuDir[] ="share/djvu/osi";
-#else /* !AUTOCONF */
-static const char ModuleDjVuDir[] ="profiles";
-#endif /* !AUTOCONF */
+static const char ProfilesDjVuDir[] ="profiles";
 static const char LocalDjVuDir[] =".DjVu";      // relative to ${HOME}
 #ifdef LT_DEFAULT_PREFIX
 static const char DjVuPrefixDir[] = LT_DEFAULT_PREFIX "/profiles";
@@ -158,22 +154,6 @@ RegOpenReadConfig ( HKEY hParentKey )
   if (RegOpenKeyEx(hParentKey, path, 0,
 		   KEY_READ, &hKey) == ERROR_SUCCESS )
   {
-#ifndef __MINGW32__
-    TCHAR path[1024];
-    TCHAR *szPathValue = path;
-    LPCTSTR lpszEntry = (LPCTSTR &)TEXT("");
-    DWORD dwCount = (sizeof(path)/sizeof(TCHAR))-1;
-    DWORD dwType;
-    LONG lResult = RegQueryValueEx(hKey, lpszEntry, NULL,
-             &dwType, (LPBYTE) szPathValue, &dwCount);
-    RegCloseKey(hKey);
-    if ((lResult == ERROR_SUCCESS))
-    {
-      szPathValue[dwCount] = 0;
-      USES_CONVERSION;
-      retval=GURL::Filename::Native(T2CA(path));
-    }
-#else
     CHAR path[1024];
     CHAR *szPathValue = path;
     LPCSTR lpszEntry = "";
@@ -187,7 +167,6 @@ RegOpenReadConfig ( HKEY hParentKey )
       szPathValue[dwCount] = 0;
       retval=GURL::Filename::Native(path);
     }
-#endif
   } 
   return retval;
 }
@@ -196,18 +175,10 @@ static GURL
 GetModulePath( void )
 {
   const GUTF8String cwd(GOS::cwd());
-#ifndef __MINGW32__
-  TCHAR path[1024];
-  DWORD dwCount = (sizeof(path)/sizeof(TCHAR))-1;
-  GetModuleFileName(0, path, dwCount);
-  USES_CONVERSION;
-  GURL retval=GURL::Filename::Native(T2CA(path)).base();
-#else
   CHAR path[1024];
   DWORD dwCount = (sizeof(path)/sizeof(CHAR))-1;
   GetModuleFileNameA(0, path, dwCount);
   GURL retval=GURL::Filename::Native(path).base();
-#endif
   GOS::cwd(cwd);
   return retval;
 }
@@ -310,12 +281,16 @@ DjVuMessage::GetProfilePaths(void)
 #endif
       appendPath(mpath,pathsmap,paths);
       appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
+      appendPath(GURL::UTF8(ProfilesDjVuDir,mpath),pathsmap,paths);
       mpath=mpath.base();
       appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
+      appendPath(GURL::UTF8(ProfilesDjVuDir,mpath),pathsmap,paths);
       mpath=mpath.base();
       appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
+      appendPath(GURL::UTF8(ProfilesDjVuDir,mpath),pathsmap,paths);
       mpath=mpath.base();
       appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
+      appendPath(GURL::UTF8(ProfilesDjVuDir,mpath),pathsmap,paths);
     }
 #endif
 #if defined(AUTOCONF)
