@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuToPS.cpp,v 1.25 2007/12/02 03:58:29 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: DjVuToPS.cpp,v 1.27 2008/08/05 20:50:35 bpearlmutter Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -1278,9 +1278,9 @@ print_bg(ByteStream &str,
   int ps_chunk_height = 30960/prn_rect.width()+1;
   buffer_size = buffer_size*23/10;
   bool do_color = options.get_color();
-  if (!dimg->is_legal_photo() && 
-      !dimg->is_legal_compound() ||
-      options.get_mode()==Options::BW) 
+  if ((!dimg->is_legal_photo() &&
+       !dimg->is_legal_compound())
+      || options.get_mode()==Options::BW)
     do_color = false;
   if (do_color) 
     buffer_size *= 3;
@@ -1915,7 +1915,7 @@ print_ps_string(const char *data, int length, ByteStream &out)
       else
         {
           char buffer[5];
-          sprintf(buffer,"\\%03o", *data);
+          sprintf(buffer,"\\%03o", *(unsigned char*)data);
           out.write(buffer,4);
           data += 1;
           length -= 1;
