@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GOS.cpp,v 1.16 2007/07/14 01:21:56 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: GOS.cpp,v 1.17 2008/03/10 13:58:54 leonb Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -74,16 +74,27 @@
 #include <math.h>
 #include <string.h>
 
-#ifdef WIN32
-# include <windows.h>
-# include <direct.h>
+#if defined(__CYGWIN32__)
+# define UNIX 1
 #endif
 
-#ifdef OS2
+#if defined(WIN32) && !defined(UNIX)
+# include <windows.h>
+# include <direct.h>
+# define getcwd _getcwd
+#endif
+
+#if defined(OS2)
 # define INCL_DOS
 # include <os2.h>
 #endif
 
+#if defined(macintosh) && !defined(UNIX)
+# include <unix.h>
+# include <errno.h>
+# include <unistd.h>
+#endif
+
 #if defined(UNIX) || defined(OS2)
 # include <errno.h>
 # include <sys/types.h>
@@ -95,20 +106,6 @@
 # include <unistd.h>
 #endif
 
-#ifdef macintosh
-# ifndef UNIX
-#  include <unix.h>
-#  include <errno.h>
-#  include <unistd.h>
-# endif
-#endif
-
-#ifdef WIN32
-# if !defined(__MINGW32__) && !defined(__CYGWIN32__)
-#  define getcwd _getcwd
-# endif
-#endif
-
 
 // -- TRUE FALSE
 #undef TRUE
@@ -173,14 +170,14 @@ static const char nillchar=0;
 static inline int
 finddirsep(const GUTF8String &fname)
 {
-#if defined(UNIX)
-  return fname.rsearch('/',0);
-#elif defined(WIN32) || defined(OS2)
+#if defined(WIN32)
   return fname.rcontains("\\/",0);
+#elif defined(UNIX)
+  return fname.rsearch('/',0);
 #elif defined(macintosh)
   return fname.rcontains(":/",0);
 #else
-#error "Define something here for your operating system"
+# error "Define something here for your operating system"
 #endif  
 }
 
@@ -350,7 +347,7 @@ GOS::cwd(const GUTF8String &dirname)
   GetFullPathName(drv, MAXPATHLEN, string_buffer, &result);
   return GNativeString(string_buffer).getNative2UTF8();//MBCS cvt
 #else
-#error "Define something here for your operating system"
+# error "Define something here for your operating system"
 #endif 
 }
 
