@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: debug.cpp,v 1.16 2007/05/12 18:53:31 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: debug.cpp,v 1.17 2008/01/27 09:24:35 leonb Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -80,9 +80,6 @@
 
 #ifdef WIN32
 # include <windows.h>  // OutputDebugString
-# ifndef __MINGW32__
-#  include <atlbase.h> // A2CT
-# endif
 #endif 
 
 
@@ -163,12 +160,7 @@ DjVuDebug::format(const char *fmt, ... )
 #ifdef WIN32
       else
         {
-# ifdef __MINGW32__
           OutputDebugStringA((const char *)buffer);
-# else
-          USES_CONVERSION;
-          OutputDebugString(A2CT((const char *)buffer));
-# endif
         }
 #endif
     }
