@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: csepdjvu.cpp,v 1.27 2007/11/30 14:39:26 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: csepdjvu.cpp,v 1.30 2008/05/05 02:22:15 leonb Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -136,7 +136,7 @@
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: csepdjvu.cpp,v 1.27 2007/11/30 14:39:26 leonb Exp $# */
+    #$Id: csepdjvu.cpp,v 1.30 2008/05/05 02:22:15 leonb Exp $# */
 //@{
 //@}
 
@@ -361,6 +361,8 @@ BufferByteStream::read_geometry(GRect &r)
     {
       if (expect(c,"+-"))
         {
+          if (c == '+')
+            expect(c,"-");
           if (! read_integer(x))
             return false;
           if (c == '-')
@@ -368,6 +370,8 @@ BufferByteStream::read_geometry(GRect &r)
         }
       if (expect(c,"+-"))
         {
+          if (c == '+')
+            expect(c,"-");
           if (! read_integer(y))
             return false;
           if (c == '-')
@@ -1071,7 +1075,7 @@ read_background(BufferByteStream &bs, int w, int h, int &bgred)
     return 0;
   GP<GPixmap> pix = GPixmap::create(bs);
   // Check background reduction
-  for (bgred=1; bgred<12; bgred++) 
+  for (bgred=1; bgred<=12; bgred++) 
     {
       int subw = (w + bgred - 1) / bgred;
       int subh = (h + bgred - 1) / bgred;
@@ -1192,6 +1196,8 @@ Comments::parse_comment_line(BufferByteStream &bs)
              bs.skip(" \t") && bs.read_geometry(mark->r) &&
              bs.skip(" \t") && bs.read_ps_string(mark->s) ) )
         G_THROW("csepdjvu: corrupted file (syntax error in text comment)");
+      if (mark->r.isempty())
+        G_THROW("csepdjvu: corrupted file (empty rectangle in text comment)");
       textmark(mark);
       return true;
     }
@@ -1202,6 +1208,8 @@ Comments::parse_comment_line(BufferByteStream &bs)
       if (! (bs.skip(" \t") && bs.read_geometry(mark->r) &&
              bs.skip(" \t") && bs.read_ps_string(mark->s) ) )
         G_THROW("csepdjvu: corrupted file (syntax error in link comment)");
+      if (mark->r.isempty())
+        G_THROW("csepdjvu: corrupted file (empty rectangle in link comment)");
       int ymax = h - mark->r.ymin - 1; // reversed in gsdjvu ?
       int ymin = h - mark->r.ymax - 1; // reversed in gsdjvu ?
       mark->r.ymax = ymax;
@@ -1764,7 +1772,7 @@ main(int argc, const char **argv)
               // Specify resolution
               char *end;
               opts.dpi = strtol(dargv[++i], &end, 10);
-              if (*end || opts.dpi<25 || opts.dpi>144000)
+              if (*end || opts.dpi<25 || opts.dpi>6000)
                 usage();
             }
           else if (arg == "-q" && i+1 < argc)
