@@ -53,7 +53,7 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ddjvu.cpp,v 1.29 2007/12/02 04:14:45 leonb Exp $
+// $Id: ddjvu.cpp,v 1.39 2009/02/13 09:46:27 leonb Exp $
 
 
 /* Program ddjvu has been rewritten to use the ddjvuapi only.
@@ -74,28 +74,33 @@
 
 #ifdef UNIX
 # include <sys/time.h>
+# include <sys/types.h>
+# include <unistd.h>
 #endif
 
 #include "libdjvu/ddjvuapi.h"
+#include "tiff2pdf.h"
 
-#if defined(WIN32) || defined(__CYGWIN32__)
+#if defined(WIN32) && !defined(__CYGWIN32__)
 # include <io.h>
+# define dup     _dup
+# define lseek   _lseek
+# define open    _open
+# define close   _close
+# define mktemp  _mktemp
+# define O_CREAT _O_CREAT
+# define O_RDWR  _O_RDWR
 #endif
+
 #if HAVE_PUTC_UNLOCKED
 # undef putc
 # define putc putc_unlocked
 #endif
+
 #if HAVE_TIFF
+# include <tiff.h>
 # include <tiffio.h>
-# ifndef COMPRESSION_CCITT_T6
-#  define COMPRESSION_CCITT_T6 4
-# endif
-# ifndef COMPRESSION_JPEG
-#  define COMPRESSION_JPEG 7
-# endif
-# ifndef COMPRESSION_PACKBITS
-#  define COMPRESSION_PACKBITS 32771
-# endif
+# include <tiffconf.h>
 #endif
 
 /* Some day we'll redo i18n right. */
@@ -128,17 +133,22 @@ int          flag_subsample = -1;
 int          flag_segment = 0;
 int          flag_verbose = 0;
 char         flag_mode = 0;     /* 'c', 'k', 's', 'f','b' */
-char         flag_format = 0;   /* '4','5','6','p','r','t' */
+char         flag_format = 0;   /* '4','5','6','p','r','t', 'f' */
 int          flag_quality = -1;
 const char  *flag_pagespec = 0; 
 ddjvu_rect_t info_size;
 ddjvu_rect_t info_segment;
-const char  *inputfilename;
-const char  *outputfilename;
+const char  *inputfilename = 0;
+const char  *outputfilename = 0;
 
-FILE *fout;
+#if HAVE_TIFF2PDF
+char *tempfilename = 0;
+int tiffd = -1;
+#endif
+
+FILE *fout = 0;
 #if HAVE_TIFF
-TIFF *tiff;
+TIFF *tiff = 0;
 #endif
 
 
@@ -183,6 +193,13 @@ die(const char *fmt, ...)
   vfprintf(stderr, fmt, args);
   va_end(args);
   fprintf(stderr,"\n");
+  /* Cleanup */
+#if HAVE_TIFF2PDF
+  if (tiffd >= 0)
+    close(tiffd);
+  if (tempfilename)
+    remove(tempfilename);
+#endif
   /* Terminates */
   exit(10);
 }
@@ -218,7 +235,7 @@ inform(ddjvu_page_t *page, int pageno)
 
 
 void
-render(ddjvu_page_t *page)
+render(ddjvu_page_t *page, int pageno)
 {
   ddjvu_rect_t prect;
   ddjvu_rect_t rrect;
@@ -230,6 +247,7 @@ render(ddjvu_page_t *page)
   int dpi = ddjvu_page_get_resolution(page);
   ddjvu_page_type_t type = ddjvu_page_get_type(page);
   char *image = 0;
+  char white = 0xFF;
   int rowsize;
 #if HAVE_TIFF
   int compression = COMPRESSION_NONE;
@@ -302,9 +320,9 @@ render(ddjvu_page_t *page)
 
   /* Determine output pixel format */
   style = DDJVU_FORMAT_RGB24;
-  if ((mode==DDJVU_RENDER_BLACK) ||
-      (mode==DDJVU_RENDER_MASKONLY) ||
-      (mode==DDJVU_RENDER_COLOR) && (type==DDJVU_PAGETYPE_BITONAL))
+  if (mode==DDJVU_RENDER_BLACK ||
+      mode==DDJVU_RENDER_MASKONLY ||
+      (mode==DDJVU_RENDER_COLOR && type==DDJVU_PAGETYPE_BITONAL))
     {
       style = DDJVU_FORMAT_GREY8;
       if ((int)prect.w == iw && (int)prect.h == ih)
@@ -313,16 +331,30 @@ render(ddjvu_page_t *page)
   switch(flag_format)
     {
     case 't':
+    case 'f':
 #if HAVE_TIFF
       compression = COMPRESSION_NONE;
+# ifdef CCITT_SUPPORT
       if (style==DDJVU_FORMAT_MSBTOLSB 
           && TIFFFindCODEC(COMPRESSION_CCITT_T6))
         compression = COMPRESSION_CCITT_T6;
-      else if (style!=DDJVU_FORMAT_MSBTOLSB && flag_quality>0 
-               && TIFFFindCODEC(COMPRESSION_JPEG))
+# endif
+# ifdef JPEG_SUPPORT
+      if (compression == COMPRESSION_NONE 
+          && style!=DDJVU_FORMAT_MSBTOLSB && flag_quality>0 
+          && TIFFFindCODEC(COMPRESSION_JPEG))
         compression = COMPRESSION_JPEG;
-      else if (TIFFFindCODEC(COMPRESSION_PACKBITS))
+# endif
+# ifdef PACKBITS_SUPPORT
+      if (compression == COMPRESSION_NONE && flag_format == 't' 
+          && TIFFFindCODEC(COMPRESSION_PACKBITS))
         compression = COMPRESSION_PACKBITS;
+# endif
+# ifdef ZIP_SUPPORT
+      else if (compression == COMPRESSION_NONE
+               && TIFFFindCODEC(COMPRESSION_DEFLATE))
+        compression = COMPRESSION_DEFLATE;
+# endif
       break;
 #endif      
     case '4':
@@ -339,22 +371,23 @@ render(ddjvu_page_t *page)
       break;
     }
   if (! (fmt = ddjvu_format_create(style, 0, 0)))
-    die(i18n("Cannot determine pixel style"));
+    die(i18n("Cannot determine pixel style for page %d"), pageno);
   ddjvu_format_set_row_order(fmt, 1);
   /* Allocate buffer */
-  if (style == DDJVU_FORMAT_MSBTOLSB)
-    rowsize = (rrect.w + 7) / 8;
-  else if (style == DDJVU_FORMAT_GREY8)
+  if (style == DDJVU_FORMAT_MSBTOLSB) {
+    white = 0x00;
+    rowsize = (rrect.w + 7) / 8; 
+  } else if (style == DDJVU_FORMAT_GREY8)
     rowsize = rrect.w;
   else
     rowsize = rrect.w * 3; 
   if (! (image = (char*)malloc(rowsize * rrect.h)))
-    die(i18n("Cannot allocate image buffer"));
+    die(i18n("Cannot allocate image buffer for page %d"), pageno);
 
   /* Render */
   timingdata[2] = ticks();
   if (! ddjvu_page_render(page, mode, &prect, &rrect, fmt, rowsize, image))
-    die(i18n("Cannot render image"));
+    memset(image, white, rowsize * rrect.h);
   timingdata[3] = ticks();
   if (flag_verbose)
     if (timingdata[2] != timingdata[3])
@@ -427,8 +460,9 @@ render(ddjvu_page_t *page)
           die(i18n("writing rle file: %s"), strerror(errno));
         break;
       }
-      /* -------------- TIFF output */
+      /* -------------- TIFF or PDF output */
     case 't':
+    case 'f':
       {
 #if HAVE_TIFF
         int i;
@@ -441,7 +475,16 @@ render(ddjvu_page_t *page)
 		     (float)((dpi*rrect.h+ih/2)/ih));
         TIFFSetField(tiff, TIFFTAG_PLANARCONFIG, PLANARCONFIG_CONTIG);
         TIFFSetField(tiff, TIFFTAG_ORIENTATION, ORIENTATION_TOPLEFT);
-        TIFFSetField(tiff, TIFFTAG_ROWSPERSTRIP, (uint32)64);
+# ifdef CCITT_SUPPORT
+        if (compression != COMPRESSION_CCITT_T6)
+# endif
+# ifdef JPEG_SUPPORT
+          if (compression != COMPRESSION_JPEG)
+# endif
+# ifdef ZIP_SUPPORT
+            if (compression != COMPRESSION_DEFLATE)
+# endif
+              TIFFSetField(tiff, TIFFTAG_ROWSPERSTRIP, (uint32)64);
         if (style == DDJVU_FORMAT_MSBTOLSB) {
           TIFFSetField(tiff, TIFFTAG_BITSPERSAMPLE, (uint16)1);
           TIFFSetField(tiff, TIFFTAG_SAMPLESPERPIXEL, (uint16)1);
@@ -457,21 +500,35 @@ render(ddjvu_page_t *page)
           } else {
             TIFFSetField(tiff, TIFFTAG_SAMPLESPERPIXEL, (uint16)3);
             TIFFSetField(tiff, TIFFTAG_COMPRESSION, compression);
+# ifdef JPEG_SUPPORT
             if (compression == COMPRESSION_JPEG) {
               TIFFSetField(tiff, TIFFTAG_PHOTOMETRIC, PHOTOMETRIC_YCBCR);
               TIFFSetField(tiff, TIFFTAG_JPEGCOLORMODE, JPEGCOLORMODE_RGB);
               TIFFSetField(tiff, TIFFTAG_JPEGQUALITY, flag_quality);
             } else 
+# endif
               TIFFSetField(tiff, TIFFTAG_PHOTOMETRIC, PHOTOMETRIC_RGB);
           }
         }
         if (flag_verbose) {
-          if (compression == COMPRESSION_CCITT_T6)
+          if (compression == COMPRESSION_NONE)
+            fprintf(stderr,i18n("Producing uncompressed TIFF file.\n"));
+# ifdef CCITT_SUPPORT
+          else if (compression == COMPRESSION_CCITT_T6)
             fprintf(stderr,i18n("Producing TIFF/G4 file.\n"));
+# endif
+# ifdef JPEG_SUPPORT
           else if (compression == COMPRESSION_JPEG)
             fprintf(stderr,i18n("Producing TIFF/JPEG file.\n"));
+# endif
+# ifdef ZIP_SUPPORT
+          else if (compression == COMPRESSION_DEFLATE)
+            fprintf(stderr,i18n("Producing TIFF/DEFLATE file.\n"));
+# endif
+# ifdef PACKBITS_SUPPORT
           else if (compression == COMPRESSION_PACKBITS)
             fprintf(stderr,i18n("Producing TIFF/PACKBITS file.\n"));
+# endif
           else
             fprintf(stderr,i18n("Producing TIFF file.\n"));
         }
@@ -507,23 +564,52 @@ dopage(int pageno)
   
   timingdata[1] = ticks();
   /* Open files */
-  if (flag_format == 't') 
+  if (flag_format == 't')
     {
 #if HAVE_TIFF
-      if (! tiff) 
-        {
-          if (! strcmp(outputfilename,"-"))
-            die(i18n("Tiff output requires a valid output file name."));
-          else if (! (tiff = TIFFOpen(outputfilename, "w")))
-            die(i18n("Cannot open output tiff file '%s'."), outputfilename);
-        } 
-      else 
+      if (tiff) 
         {
           if (! TIFFWriteDirectory(tiff))
             die(i18n("Problem writing TIFF directory."));
         }
+      else
+        {
+          if (! strcmp(outputfilename,"-"))
+            die(i18n("TIFF output requires a valid output file name."));
+          if (! (tiff = TIFFOpen(outputfilename, "w")))
+            die(i18n("Cannot open output tiff file '%s'."), outputfilename);
+        }
 #else
       die(i18n("TIFF output is not compiled"));
+#endif
+    }
+  else if (flag_format == 'f')  
+    {
+#if HAVE_TIFF2PDF
+      if (tiff) 
+        {
+          if (! TIFFWriteDirectory(tiff))
+            die(i18n("Problem writing TIFF directory."));
+        }
+      else
+        {
+          if (! strcmp(outputfilename,"-"))
+            die(i18n("PDF output requires a valid output file name."));
+          if (! (tempfilename = (char*)malloc(strlen(outputfilename) + 8)))
+            die(i18n("Out of memory."));
+          strcpy(tempfilename, outputfilename);
+          strcat(tempfilename, ".XXXXXX");
+# if HAVE_MKSTEMP
+          tiffd = mkstemp(tempfilename);
+# else
+          if (mktemp(tempfilename))
+            tiffd = open(tempfilename, O_RDWR|O_CREAT);
+# endif
+          if (tiffd < 0 || ! (tiff = TIFFFdOpen(tiffd, tempfilename, "w")))
+            die(i18n("Cannot create temporary tiff file '%s'."), tempfilename);
+        }
+#else
+      die(i18n("PDF output is not compiled"));
 #endif
     } 
   else if (! fout) 
@@ -540,7 +626,7 @@ dopage(int pageno)
     }
   /* Render */
   inform(page, pageno);
-  render(page);
+  render(page, pageno);
   ddjvu_page_release(page);
 }
 
@@ -831,8 +917,10 @@ parse_option(int argc, char **argv, int i)
         flag_format='r';
       else if (!strcmp(arg,"tiff") || !strcmp(arg,"tif"))
         flag_format='t';
+      else if (!strcmp(arg,"pdf"))
+        flag_format='f';
       else
-        die(i18n(errbadarg),opt,i18n("are: pbm,pgm,ppm,pnm,rle,tiff"));
+        die(i18n(errbadarg),opt,i18n("are: pbm,pgm,ppm,pnm,rle,tiff,pdf"));
     }
   else if (!strcmp(opt,"mode"))
     {
@@ -928,6 +1016,37 @@ main(int argc, char **argv)
   parse_pagespec(flag_pagespec, i, dopage);
 
   /* Close */
+#if HAVE_TIFF2PDF
+  if (tiff && tiffd >= 0 && tempfilename)
+    {
+      int fd = dup(tiffd);
+      if (! TIFFFlush(tiff))
+        die(i18n("Error while flushing TIFF file."));
+      TIFFClose(tiff);
+      close(tiffd);
+      tiffd = fd;
+      if (flag_verbose)
+        fprintf(stderr,i18n("Converting temporary TIFF to PDF.\n"));
+      lseek(tiffd, 0, SEEK_SET);
+      if (! (tiff = TIFFFdOpen(tiffd, tempfilename, "r")))
+        die(i18n("Cannot reopen temporary tiff file '%s'."), tempfilename);
+      if (! (fout = fopen(outputfilename, "wb")))
+        die(i18n("Cannot open output file '%s'."), outputfilename);
+      const char *args[3];
+      args[0] = argv[0];
+      args[1] = "-o";
+      args[2] = outputfilename;
+      if (tiff2pdf(tiff, fout, 3, args) != EXIT_SUCCESS)
+        die(i18n("Error occured while creating PDF file."));
+      TIFFClose(tiff);
+      tiff = 0;
+      close(tiffd);
+      tiffd = -1;
+      remove(tempfilename);
+      free(tempfilename);
+      tempfilename = 0;
+    }
+#endif
 #if HAVE_TIFF
   if (tiff)
     {
