@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: djvutoxml.cpp,v 1.8 2007/03/25 20:48:36 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: djvutoxml.cpp,v 1.9 2008/01/27 11:36:30 leonb Exp $
+// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -139,18 +139,6 @@ main(int argc, char * argv[], char *env[])
     flags|=DjVuImage::NOMAP;
   if(notext > 0)
     flags|=DjVuImage::NOTEXT;
-#ifdef DEBUG_SET_LEVEL
-  {
-    static GUTF8String debug=GOS::getenv("DEBUG");
-    if (debug.length())
-    {
-      int level=debug.is_int()?debug.toInt():0;
-      if (level<1) level=1;
-      if (level>32) level=32;
-      DEBUG_SET_LEVEL(level);
-    }
-  }
-#endif
     
   G_TRY
   {
